@@ -322,6 +322,14 @@ static int snd_pcm_dsnoop_status(snd_pcm_t *pcm, snd_pcm_status_t * status)
 {
 	snd_pcm_direct_t *dsnoop = pcm->private_data;
 
+	switch(dsnoop->state) {
+	case SNDRV_PCM_STATE_DRAINING:
+	case SNDRV_PCM_STATE_RUNNING:
+		snd_pcm_dsnoop_sync_ptr(pcm);
+		break;
+	default:
+		break;
+	}
 	memset(status, 0, sizeof(*status));
 	status->state = dsnoop->state;
 	status->trigger_tstamp = dsnoop->trigger_tstamp;
@@ -928,8 +936,8 @@ int _snd_pcm_dsnoop_open(snd_pcm_t **pcmp, const char *name,
 				 SND_PCM_HW_PARAM_CHANNELS, 0, &params.channels,
 				 SND_PCM_HW_PARAM_PERIOD_TIME, 0, &params.period_time,
 				 SND_PCM_HW_PARAM_BUFFER_TIME, 0, &params.buffer_time,
-				 SND_PCM_HW_PARAM_PERIOD_SIZE, 0, &bsize,
-				 SND_PCM_HW_PARAM_BUFFER_SIZE, 0, &psize,
+				 SND_PCM_HW_PARAM_PERIOD_SIZE, 0, &psize,
+				 SND_PCM_HW_PARAM_BUFFER_SIZE, 0, &bsize,
 				 SND_PCM_HW_PARAM_PERIODS, 0, &params.periods);
 	if (err < 0)
 		return err;
